/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "sandboxscene.h"

framedtextmenu_t ftm;

bool sandboxSceneInit(sandboxscene_t *game) {
  assetFontLoad(&game->font, "fonts/opensans/OpenSans-Regular.ttf");
  assetTextureLoad(&game->texture, "test_texture.png");
  assetShaderLoad(&game->shader, 
    "shaders/textured.vert", "shaders/textured.frag"
  );

  menuitem_t *item;
  framedTextMenuInit(&ftm, &game->font, &game->texture);
  ftm.menu.grid.rows = 3;
  item = textMenuAdd(&ftm.menu, "Option 1");
  item->y = 0;
  item = textMenuAdd(&ftm.menu, "Option 2");
  item->y = 1;
  item = textMenuAdd(&ftm.menu, "Option 3");
  item->y = 2;

  return true;
}

void sandboxSceneUpdate(sandboxscene_t *game, engine_t *engine) {
  cameraLookAt(&game->camera,
    0, 0, 10,
    0, 0, 0
  );

  cameraOrtho(&game->camera,
    0, engine->render.width,
    engine->render.height, 0,
    0.01f, 1000.0f
  );

  shaderUse(&game->shader);
  shaderUseCamera(&game->shader, &game->camera);

  framedTextMenuResize(&ftm, 400, 400);
  framedTextMenuUpdate(&ftm, engine);
  framedTextMenuRender(&ftm, &game->shader, 0, 0);
}

void sandboxSceneDispose(sandboxscene_t *game) {

}